#include <DS3231.h>
#include <TMCStepper.h>
#include <Adafruit_SSD1306.h>
#include <EEPROM.h>

#define PIN_ENABLE          8 // Enable
#define PIN_DIR             12 // Direction
#define PIN_STEP            10 // Step
#define PIN_SWITCH          18 //switch

#define SW_RX               63 // TMC2208/TMC2224 SoftwareSerial receive pin
#define SW_TX               40 // TMC2208/TMC2224 SoftwareSerial transmit pinf
#define DRIVER_ADDRESS      0b00 // TMC2209 Driver address according to MS1 and MS2
#define R_SENSE             0.11f // Match to your driver, SilentStepStick series use 0.11

TMC2209Stepper driver(SW_RX, SW_TX, R_SENSE, DRIVER_ADDRESS);


void setup()
{
  Serial.begin(115200);  
    
  
  pinMode(PIN_ENABLE, OUTPUT);
  pinMode(PIN_STEP, OUTPUT);
  pinMode(PIN_DIR, OUTPUT);
  pinMode(PIN_SWITCH, INPUT);
  digitalWrite(PIN_ENABLE, HIGH);  // Enable driver in hardware

  driver.begin();                 //  SPI: Init CS pins and possible SW SPI pins
                                  // UART: Init SW UART (if selected) with default 115200 baudrate
  driver.toff(5);                 // Enables driver in software
  driver.rms_current(800);        // Set motor RMS current
  driver.microsteps(16);          // Set microsteps to 1/16th

  driver.pwm_autoscale(true);     // Needed for stealthChop
  findZeroPosition();  
}

void loop() 
{
  turn(5, false, 300);
  delay(5000);
  findZeroPosition();
  delay(5000);
  
  //Serial.println(digitalRead(PIN_SWITCH));
  //delay(200);
}

void findZeroPosition()
{
  
  while(digitalRead(PIN_SWITCH)==0) //not found zero position yet
  {
    turn(0.05, true, 300);
  }
}

void turn(float n_turns, bool up, int delay_microseconds)
{
  digitalWrite(PIN_ENABLE, LOW);
  if(up)
  {
    digitalWrite(PIN_DIR,HIGH);
  }
  else
  {
    digitalWrite(PIN_DIR,LOW);    
  }
  
  for (long i = (long)(1600.0*n_turns); i>0; i--)
  {
    digitalWrite(PIN_STEP, HIGH);
    delayMicroseconds(delay_microseconds);
    digitalWrite(PIN_STEP, LOW);
    delayMicroseconds(delay_microseconds);
  }
  digitalWrite(PIN_ENABLE, HIGH);
}
